@@ -9,9 +9,8 @@ import pydantic_core
 
 from ..config import ConfigDict
 from ..plugin._schema_validator import create_schema_validator
-from . import _discriminated_union, _generate_schema, _typing_extra
+from . import _generate_schema, _typing_extra
 from ._config import ConfigWrapper
-from ._core_utils import simplify_schema_references, validate_core_schema
 
 
 @dataclass
@@ -47,12 +46,14 @@ class ValidateCallWrapper:
         self.__signature__ = inspect.signature(function)
         if isinstance(function, partial):
             func = function.func
+            schema_type = func
             self.__name__ = f'partial({func.__name__})'
             self.__qualname__ = f'partial({func.__qualname__})'
             self.__annotations__ = func.__annotations__
             self.__module__ = func.__module__
             self.__doc__ = func.__doc__
         else:
+            schema_type = function
             self.__name__ = function.__name__
             self.__qualname__ = function.__qualname__
             self.__annotations__ = function.__annotations__
@@ -62,12 +63,19 @@ class ValidateCallWrapper:
         namespace = _typing_extra.add_module_globals(function, None)
         config_wrapper = ConfigWrapper(config)
         gen_schema = _generate_schema.GenerateSchema(config_wrapper, namespace)
-        schema = gen_schema.collect_definitions(gen_schema.generate_schema(function))
-        schema = simplify_schema_references(schema)
-        self.__pydantic_core_schema__ = schema = schema
+        schema = gen_schema.clean_schema(gen_schema.generate_schema(function))
+        self.__pydantic_core_schema__ = schema
         core_config = config_wrapper.core_config(self)
-        schema = _discriminated_union.apply_discriminators(schema)
-        self.__pydantic_validator__ = create_schema_validator(schema, core_config, config_wrapper.plugin_settings)
+
+        self.__pydantic_validator__ = create_schema_validator(
+            schema,
+            schema_type,
+            self.__module__,
+            self.__qualname__,
+            'validate_call',
+            core_config,
+            config_wrapper.plugin_settings,
+        )
 
         if self._validate_return:
             return_type = (
@@ -76,12 +84,17 @@ class ValidateCallWrapper:
                 else Any
             )
             gen_schema = _generate_schema.GenerateSchema(config_wrapper, namespace)
-            schema = gen_schema.collect_definitions(gen_schema.generate_schema(return_type))
-            schema = _discriminated_union.apply_discriminators(simplify_schema_references(schema))
+            schema = gen_schema.clean_schema(gen_schema.generate_schema(return_type))
             self.__return_pydantic_core_schema__ = schema
-            core_config = config_wrapper.core_config(self)
-            schema = validate_core_schema(schema)
-            validator = pydantic_core.SchemaValidator(schema, core_config)
+            validator = create_schema_validator(
+                schema,
+                schema_type,
+                self.__module__,
+                self.__qualname__,
+                'validate_call',
+                core_config,
+                config_wrapper.plugin_settings,
+            )
             if inspect.iscoroutinefunction(self.raw_function):
 
                 async def return_val_wrapper(aw: Awaitable[Any]) -> None:
@@ -114,6 +127,11 @@ class ValidateCallWrapper:
 
         bound_function = self.raw_function.__get__(obj, objtype)
         result = self.__class__(bound_function, self._config, self._validate_return)
+
+        # skip binding to instance when obj or objtype has __slots__ attribute
+        if hasattr(obj, '__slots__') or hasattr(objtype, '__slots__'):
+            return result
+
         if self._name is not None:
             if obj is not None:
                 object.__setattr__(obj, self._name, result)
@@ -126,3 +144,13 @@ class ValidateCallWrapper:
 
     def __repr__(self) -> str:
         return f'ValidateCallWrapper({self.raw_function})'
+
+    def __eq__(self, other) -> bool:
+        return (
+            (self.raw_function == other.raw_function)
+            and (self._config == other._config)
+            and (self._validate_return == other._validate_return)
+        )
+
+    def __hash__(self):
+        return hash(self.raw_function)
