@@ -1,6 +1,7 @@
 """Logic for creating models."""
 from __future__ import annotations as _annotations
 
+import sys
 import types
 import typing
 import warnings
@@ -27,7 +28,6 @@ from ._migration import getattr_migration
 from .annotated_handlers import GetCoreSchemaHandler, GetJsonSchemaHandler
 from .config import ConfigDict
 from .errors import PydanticUndefinedAnnotation, PydanticUserError
-from .fields import ComputedFieldInfo, FieldInfo, ModelPrivateAttr
 from .json_schema import DEFAULT_REF_TEMPLATE, GenerateJsonSchema, JsonSchemaMode, JsonSchemaValue, model_json_schema
 from .warnings import PydanticDeprecatedSince20
 
@@ -40,9 +40,9 @@ if typing.TYPE_CHECKING:
 
     from ._internal._utils import AbstractSetIntStr, MappingIntStrAny
     from .deprecated.parse import Protocol as DeprecatedParseProtocol
+    from .fields import ComputedFieldInfo, FieldInfo, ModelPrivateAttr
     from .fields import Field as _Field
 
-    AnyClassMethod = classmethod[Any, Any, Any]
     TupleGenerator = typing.Generator[typing.Tuple[str, Any], None, None]
     Model = typing.TypeVar('Model', bound='BaseModel')
     # should be `set[int] | set[str] | dict[int, IncEx] | dict[str, IncEx] | None`, but mypy can't cope
@@ -58,7 +58,7 @@ _object_setattr = _model_construction.object_setattr
 
 
 class BaseModel(metaclass=_model_construction.ModelMetaclass):
-    """Usage docs: https://docs.pydantic.dev/2.4/concepts/models/
+    """Usage docs: https://docs.pydantic.dev/2.5/concepts/models/
 
     A base class for creating Pydantic models.
 
@@ -82,7 +82,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
 
         __pydantic_extra__: An instance attribute with the values of extra fields from validation when
             `model_config['extra'] == 'allow'`.
-        __pydantic_fields_set__: An instance attribute with the names of fields explicitly specified during validation.
+        __pydantic_fields_set__: An instance attribute with the names of fields explicitly set.
         __pydantic_private__: Instance attribute with the values of private attributes set on the model instance.
     """
 
@@ -186,7 +186,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
 
     @property
     def model_fields_set(self) -> set[str]:
-        """Returns the set of fields that have been set on this model instance.
+        """Returns the set of fields that have been explicitly set on this model instance.
 
         Returns:
             A set of strings representing the fields that have been set,
@@ -245,7 +245,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         return m
 
     def model_copy(self: Model, *, update: dict[str, Any] | None = None, deep: bool = False) -> Model:
-        """Usage docs: https://docs.pydantic.dev/2.4/concepts/serialization/#model_copy
+        """Usage docs: https://docs.pydantic.dev/2.5/concepts/serialization/#model_copy
 
         Returns a copy of the model.
 
@@ -285,7 +285,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         round_trip: bool = False,
         warnings: bool = True,
     ) -> dict[str, Any]:
-        """Usage docs: https://docs.pydantic.dev/2.4/concepts/serialization/#modelmodel_dump
+        """Usage docs: https://docs.pydantic.dev/2.5/concepts/serialization/#modelmodel_dump
 
         Generate a dictionary representation of the model, optionally specifying which fields to include or exclude.
 
@@ -296,7 +296,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
             include: A list of fields to include in the output.
             exclude: A list of fields to exclude from the output.
             by_alias: Whether to use the field's alias in the dictionary key if defined.
-            exclude_unset: Whether to exclude fields that are unset or None from the output.
+            exclude_unset: Whether to exclude fields that have not been explicitly set.
             exclude_defaults: Whether to exclude fields that are set to their default value from the output.
             exclude_none: Whether to exclude fields that have a value of `None` from the output.
             round_trip: Whether to enable serialization and deserialization round-trip support.
@@ -331,7 +331,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         round_trip: bool = False,
         warnings: bool = True,
     ) -> str:
-        """Usage docs: https://docs.pydantic.dev/2.4/concepts/serialization/#modelmodel_dump_json
+        """Usage docs: https://docs.pydantic.dev/2.5/concepts/serialization/#modelmodel_dump_json
 
         Generates a JSON representation of the model using Pydantic's `to_json` method.
 
@@ -512,7 +512,9 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
         strict: bool | None = None,
         context: dict[str, Any] | None = None,
     ) -> Model:
-        """Validate the given JSON data against the Pydantic model.
+        """Usage docs: https://docs.pydantic.dev/2.5/concepts/json/#json-parsing
+
+        Validate the given JSON data against the Pydantic model.
 
         Args:
             json_data: The JSON data to validate.
@@ -774,20 +776,8 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
                 else:
                     self.__pydantic_private__[name] = value
             return
-        elif self.model_config.get('frozen', None):
-            error: pydantic_core.InitErrorDetails = {
-                'type': 'frozen_instance',
-                'loc': (name,),
-                'input': value,
-            }
-            raise pydantic_core.ValidationError.from_exception_data(self.__class__.__name__, [error])
-        elif getattr(self.model_fields.get(name), 'frozen', False):
-            error: pydantic_core.InitErrorDetails = {
-                'type': 'frozen_field',
-                'loc': (name,),
-                'input': value,
-            }
-            raise pydantic_core.ValidationError.from_exception_data(self.__class__.__name__, [error])
+
+        self._check_frozen(name, value)
 
         attr = getattr(self.__class__, name, None)
         if isinstance(attr, property):
@@ -798,8 +788,17 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
             # TODO - matching error
             raise ValueError(f'"{self.__class__.__name__}" object has no field "{name}"')
         elif self.model_config.get('extra') == 'allow' and name not in self.model_fields:
-            # SAFETY: __pydantic_extra__ is not None when extra = 'allow'
-            self.__pydantic_extra__[name] = value  # type: ignore
+            if self.model_extra and name in self.model_extra:
+                self.__pydantic_extra__[name] = value  # type: ignore
+            else:
+                try:
+                    getattr(self, name)
+                except AttributeError:
+                    # attribute does not already exist on instance, so put it in extra
+                    self.__pydantic_extra__[name] = value  # type: ignore
+                else:
+                    # attribute _does_ already exist on instance, and was not in extra, so update it
+                    _object_setattr(self, name, value)
         else:
             self.__dict__[name] = value
             self.__pydantic_fields_set__.add(name)
@@ -814,9 +813,13 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
             try:
                 # Note: self.__pydantic_private__ cannot be None if self.__private_attributes__ has items
                 del self.__pydantic_private__[item]  # type: ignore
+                return
             except KeyError as exc:
                 raise AttributeError(f'{type(self).__name__!r} object has no attribute {item!r}') from exc
-        elif item in self.model_fields:
+
+        self._check_frozen(item, None)
+
+        if item in self.model_fields:
             object.__delattr__(self, item)
         elif self.__pydantic_extra__ is not None and item in self.__pydantic_extra__:
             del self.__pydantic_extra__[item]
@@ -826,6 +829,20 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
             except AttributeError:
                 raise AttributeError(f'{type(self).__name__!r} object has no attribute {item!r}')
 
+    def _check_frozen(self, name: str, value: Any) -> None:
+        if self.model_config.get('frozen', None):
+            typ = 'frozen_instance'
+        elif getattr(self.model_fields.get(name), 'frozen', False):
+            typ = 'frozen_field'
+        else:
+            return
+        error: pydantic_core.InitErrorDetails = {
+            'type': typ,
+            'loc': (name,),
+            'input': value,
+        }
+        raise pydantic_core.ValidationError.from_exception_data(self.__class__.__name__, [error])
+
     def __getstate__(self) -> dict[Any, Any]:
         private = self.__pydantic_private__
         if private:
@@ -1095,7 +1112,7 @@ class BaseModel(metaclass=_model_construction.ModelMetaclass):
 
     @classmethod
     @typing_extensions.deprecated(
-        "The `from_orm` method is deprecated; set "
+        'The `from_orm` method is deprecated; set '
         "`model_config['from_attributes']=True` and use `model_validate` instead.",
         category=PydanticDeprecatedSince20,
     )
@@ -1305,9 +1322,10 @@ def create_model(
     __model_name: str,
     *,
     __config__: ConfigDict | None = None,
+    __doc__: str | None = None,
     __base__: None = None,
     __module__: str = __name__,
-    __validators__: dict[str, AnyClassMethod] | None = None,
+    __validators__: dict[str, classmethod] | None = None,
     __cls_kwargs__: dict[str, Any] | None = None,
     **field_definitions: Any,
 ) -> type[BaseModel]:
@@ -1319,22 +1337,24 @@ def create_model(
     __model_name: str,
     *,
     __config__: ConfigDict | None = None,
+    __doc__: str | None = None,
     __base__: type[Model] | tuple[type[Model], ...],
     __module__: str = __name__,
-    __validators__: dict[str, AnyClassMethod] | None = None,
+    __validators__: dict[str, classmethod] | None = None,
     __cls_kwargs__: dict[str, Any] | None = None,
     **field_definitions: Any,
 ) -> type[Model]:
     ...
 
 
-def create_model(
+def create_model(  # noqa: C901
     __model_name: str,
     *,
     __config__: ConfigDict | None = None,
+    __doc__: str | None = None,
     __base__: type[Model] | tuple[type[Model], ...] | None = None,
-    __module__: str = __name__,
-    __validators__: dict[str, AnyClassMethod] | None = None,
+    __module__: str | None = None,
+    __validators__: dict[str, classmethod] | None = None,
     __cls_kwargs__: dict[str, Any] | None = None,
     __slots__: tuple[str, ...] | None = None,
     **field_definitions: Any,
@@ -1345,10 +1365,11 @@ def create_model(
     Args:
         __model_name: The name of the newly created model.
         __config__: The configuration of the new model.
+        __doc__: The docstring of the new model.
         __base__: The base class for the new model.
-        __module__: The name of the module that the model belongs to.
-        __validators__: A dictionary of methods that validate
-            fields.
+        __module__: The name of the module that the model belongs to,
+            if `None` the value is taken from `sys._getframe(1)`
+        __validators__: A dictionary of methods that validate fields.
         __cls_kwargs__: A dictionary of keyword arguments for class creation.
         __slots__: Deprecated. Should not be passed to `create_model`.
         **field_definitions: Attributes of the new model. They should be passed in the format:
@@ -1399,7 +1420,13 @@ def create_model(
             annotations[f_name] = f_annotation
         fields[f_name] = f_value
 
+    if __module__ is None:
+        f = sys._getframe(1)
+        __module__ = f.f_globals['__name__']
+
     namespace: dict[str, Any] = {'__annotations__': annotations, '__module__': __module__}
+    if __doc__:
+        namespace.update({'__doc__': __doc__})
     if __validators__:
         namespace.update(__validators__)
     namespace.update(fields)
@@ -1410,7 +1437,15 @@ def create_model(
     if resolved_bases is not __base__:
         ns['__orig_bases__'] = __base__
     namespace.update(ns)
-    return meta(__model_name, resolved_bases, namespace, __pydantic_reset_parent_namespace__=False, **kwds)
+
+    return meta(
+        __model_name,
+        resolved_bases,
+        namespace,
+        __pydantic_reset_parent_namespace__=False,
+        _create_model_module=__module__,
+        **kwds,
+    )
 
 
 __getattr__ = getattr_migration(__name__)
